https://github.com/python/cpython/commit/69b08c397b92b6353406cec53f2b927fab1199d0
commit: 69b08c397b92b6353406cec53f2b927fab1199d0
branch: main
author: Bartosz SÅ‚awecki <[email protected]>
committer: DinoV <[email protected]>
date: 2026-03-27T14:35:50-07:00
summary:

gh-145057: Fix test names and comments to reflect `sys.lazy_modules` is a dict, 
not a set (#146084)

Fix test names and comments to reflect sys.lazy_modules is a dict, not a set

files:
M Lib/test/test_lazy_import/__init__.py

diff --git a/Lib/test/test_lazy_import/__init__.py 
b/Lib/test/test_lazy_import/__init__.py
index 328f2906f90159..6e53e2c042bc16 100644
--- a/Lib/test/test_lazy_import/__init__.py
+++ b/Lib/test/test_lazy_import/__init__.py
@@ -484,8 +484,8 @@ def my_filter(name):
         sys.set_lazy_imports_filter(my_filter)
         self.assertIs(sys.get_lazy_imports_filter(), my_filter)
 
-    def test_lazy_modules_attribute_is_set(self):
-        """sys.lazy_modules should be a set per PEP 810."""
+    def test_lazy_modules_attribute_is_dict(self):
+        """sys.lazy_modules should be a dict per PEP 810."""
         self.assertIsInstance(sys.lazy_modules, dict)
 
     @support.requires_subprocess()
@@ -966,7 +966,7 @@ def test_module_added_to_lazy_modules_on_lazy_import(self):
 
     def test_lazy_modules_is_per_interpreter(self):
         """Each interpreter should have independent sys.lazy_modules."""
         # Basic test that sys.lazy_modules exists and is a set
         self.assertIsInstance(sys.lazy_modules, dict)
 
 
@@ -1575,7 +1575,7 @@ def access_modules(idx):
         self.assertEqual(result.returncode, 0, f"stdout: {result.stdout}, 
stderr: {result.stderr}")
         self.assertIn("OK", result.stdout)
 
-    def test_concurrent_lazy_modules_set_updates(self):
+    def test_concurrent_lazy_modules_dict_updates(self):
         """Multiple threads creating lazy imports should safely update 
sys.lazy_modules."""
         code = textwrap.dedent("""
@@ -966,7 +966,7 @@ def test_module_added_to_lazy_modules_on_lazy_import(self):
     def test_lazy_modules_is_per_interpreter(self):
         """Each interpreter should have independent sys.lazy_modules."""
-        # Basic test that sys.lazy_modules exists and is a set
+        # Basic test that sys.lazy_modules exists and is a dict
         self.assertIsInstance(sys.lazy_modules, dict)
 
             import sys

_______________________________________________
Python-checkins mailing list -- [email protected]
To unsubscribe send an email to [email protected]
https://mail.python.org/mailman3//lists/python-checkins.python.org
Member address: [email protected]

Reply via email to